@@ -32,36 +32,24 @@
 
 enum {
 	ERR_SUCCESS,
-	ERR_OPEN_FILE_GROUP,
-	ERR_FAILED_ADDITIONAL_GIDS,
-	ERR_OPEN_FILE_PASSWD,
-	ERR_INVALID_USERNAME,
-	ERR_FAILED_CRYPT,
-	ERR_WRONG_PASSWD,
-	ERR_FAILED_SET_GID,
-	ERR_FAILED_SET_UID,
+	ERR_WRONG_USER_OR_PASSWD,
 	ERR_COMMAND_NOT_FOUND,
 	ERR_PERMISSION_DENIED,
 	ERR_MISSING_COMMAND,
-	ERR_FAILED_SETUID,
 	ERR_MISSING_USER_AND_COMMAND,
-	ERR_MISSING_MESSAGE_AND_COMMAND
+	ERR_MISSING_MESSAGE_AND_COMMAND,
+	ERR_CALLING_SU,
+	ERR_INVALID_COMMAND
 };
 
 static const char *KTS_ERRORS[] = {
 	"Success",
-	"Unable to open /etc/group",
-	"Unable to set additional group IDs",
-	"Unable to open /etc/passwd",
-	"Invalid username",
-	"Encryption failed",
-	"Wrong password",
-	"Unable to set group ID",
-	"Unable to set user ID",
+	"Invalid username or password",
 	"Command not found",
 	"Permission denied",
 	"No command given",
-	"SetUID error",
 	"No user and command specified",
-	"No message and command specified"
+	"No message and command specified",
+	"Unknown error calling the su command",
+	"Command passed is invalid"
 };
